# BEGIN COPYRIGHT
# *************************************************************************
#
# IBM Confidential
# OCO Source Materials
# These are as-is scripts given only as a guide.
# 5724-M24
# (C) Copyright IBM Corporation 2008
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#
# *************************************************************************
# END COPYRIGHT

#This script can be called from a command-line wrapper script or from the profile upgrade framework.
#If called from the framework, then the System properties will hold the relevant parameters.
#If called from the command-line then the expected parameters are either: 
#[wasHome, clusterName] or [wasHome, nodeName, serverName]


from java.lang import System
import zipfile

#*******************************************************************************************************
#This function implements the profile upgrade framework definition that accepts
#an applicationName, nodeName, serverName, and clusterName).  It will be called by the
#framework function updateDeploymentTargetsOf.  Either the nodeName/serverName pair will be specified
#or the clusterName parameter will be specified.  The others will be None
#wasHome is expected to be previously defined
#*******************************************************************************************************
def upgradeBPMAdministrationWidgets(appName, nodeName, serverName, clusterName):

  if ( clusterName is not None ):
    print "clusterName: "+clusterName
    updateScopeArgs = '-clusterName "' + clusterName + '"'
  elif ( (nodeName is not None) and (serverName is not None) ):
    print "nodeName: "+nodeName
    print "serverName: "+serverName
    updateScopeArgs = '-serverName "' + serverName + '" -nodeName "' + nodeName + '"'
  #endif

  #check to see if the profile should be upgraded
  upgradeProfileFlag = 1;

  print "Upgrade the profile?: " + repr(upgradeProfileFlag)
  
  if (upgradeProfileFlag):

    #Update widgets
    updateWidgetsArgs = '[' + updateScopeArgs  
    updateWidgetsArgs = updateWidgetsArgs + ' -widgets "' +wasHome + '/BusinessSpace/widgets/WESB/BPMAdministrationWidgets.zip"' 
    updateWidgetsArgs = updateWidgetsArgs + ' -save "false"'  + ' -noEndpoints "true"' + ']'

    print "updateWidgetsArgs: "+updateWidgetsArgs
    AdminTask.updateBusinessSpaceWidgets(updateWidgetsArgs)
    
    #save
    AdminConfig.save()

    print "The BPMAdministrationWidgets upgrade complete on target "+updateScopeArgs
  else:
    #The profile upgrade has already completed for this target, no need to rerun.
    print "The profile upgrade is not necessary"
  #endif
#enddef

#Main

#initialize the variables
wasHome = None
clusterName = None
appSubfixName = None
nodeName = None
serverName = None

#nodeType will be in the System properties if this script is called via the upgrade framework
nodeType = System.getProperty("bpm.upgrade.node.type")

print

if (nodeType is None):  #script called from command line
  if ((len(sys.argv) == 2)):
    wasHome = sys.argv[0]
    clusterName = sys.argv[1]
  elif ((len(sys.argv) == 3)):
    wasHome = sys.argv[0]
    nodeName = sys.argv[1]
    serverName= sys.argv[2]
  else:
    print "Incorrect Parameters"
    sys.exit(-1)
  #endif
  upgradeBPMAdministrationWidgets('BPMAdministrationWidgets', nodeName, serverName, clusterName)

else:	#script called from upgrade framework
  wasHome = System.getProperty("was.install.root")

  #Use the framework's "updateDeploymentTargetsOf" function to invoke
  #the above callable (function) for each deployment target where an
  #application whose name starts with "BPMAdministrationWidgets" is deployed.
  appNames = [appName for appName in wsadminToList(AdminApp.list()) if appName.startswith("BPMAdministrationWidgets") ]
  updateDeploymentTargetsOf(appNames, upgradeBPMAdministrationWidgets)  
#endif

print

#end Main
